@@ -360,49 +360,20 @@ const gchar*    gst_message_type_get_name       (GstMessageType type);
 GST_API
 GQuark          gst_message_type_to_quark       (GstMessageType type);
 
+#ifndef GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS
 /* refcounting */
-/**
- * gst_message_ref: (skip)
- * @msg: the message to ref
- *
- * Convenience macro to increase the reference count of the message.
- *
- * Returns: @msg (for convenience when doing assignments)
- */
-static inline GstMessage * gst_message_ref (GstMessage * msg);
 static inline GstMessage *
 gst_message_ref (GstMessage * msg)
 {
   return (GstMessage *) gst_mini_object_ref (GST_MINI_OBJECT_CAST (msg));
 }
 
-/**
- * gst_message_unref: (skip)
- * @msg: the message to unref
- *
- * Convenience macro to decrease the reference count of the message, possibly
- * freeing it.
- */
-static inline void gst_message_unref (GstMessage * msg);
 static inline void
 gst_message_unref (GstMessage * msg)
 {
   gst_mini_object_unref (GST_MINI_OBJECT_CAST (msg));
 }
 
-/**
- * gst_clear_message: (skip)
- * @msg_ptr: a pointer to a #GstMessage reference
- *
- * Clears a reference to a #GstMessage.
- *
- * @msg_ptr must not be %NULL.
- *
- * If the reference is %NULL then this function does nothing. Otherwise, the
- * reference count of the message is decreased and the pointer is set to %NULL.
- *
- * Since: 1.16
- */
 static inline void
 gst_clear_message (GstMessage ** msg_ptr)
 {
@@ -410,22 +381,25 @@ gst_clear_message (GstMessage ** msg_ptr)
 }
 
 /* copy message */
-/**
- * gst_message_copy: (skip)
- * @msg: the message to copy
- *
- * Creates a copy of the message. Returns a copy of the message.
- *
- * Returns: (transfer full): a new copy of @msg.
- *
- * MT safe
- */
 static inline GstMessage * gst_message_copy (const GstMessage * msg);
 static inline GstMessage *
 gst_message_copy (const GstMessage * msg)
 {
   return GST_MESSAGE_CAST (gst_mini_object_copy (GST_MINI_OBJECT_CONST_CAST (msg)));
 }
+#else /* GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS */
+GST_API
+GstMessage *  gst_message_ref   (GstMessage * msg);
+
+GST_API
+void          gst_message_unref (GstMessage * msg);
+
+GST_API
+void          gst_clear_message (GstMessage ** msg_ptr);
+
+GST_API
+GstMessage *  gst_message_copy  (const GstMessage * msg);
+#endif /* GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS */
 
 /**
  * gst_message_is_writable:
@@ -447,22 +421,8 @@ gst_message_copy (const GstMessage * msg)
  * MT safe
  */
 #define         gst_message_make_writable(msg)  GST_MESSAGE_CAST (gst_mini_object_make_writable (GST_MINI_OBJECT_CAST (msg)))
-/**
- * gst_message_replace: (skip)
- * @old_message: (inout) (transfer full) (nullable): pointer to a
- *     pointer to a #GstMessage to be replaced.
- * @new_message: (allow-none) (transfer none): pointer to a #GstMessage that will
- *     replace the message pointed to by @old_message.
- *
- * Modifies a pointer to a #GstMessage to point to a different #GstMessage. The
- * modification is done atomically (so this is useful for ensuring thread safety
- * in some cases), and the reference counts are updated appropriately (the old
- * message is unreffed, the new one is reffed).
- *
- * Either @new_message or the #GstMessage pointed to by @old_message may be %NULL.
- *
- * Returns: %TRUE if @new_message was different from @old_message
- */
+
+#ifndef GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS
 static inline gboolean gst_message_replace (GstMessage **old_message, GstMessage *new_message);
 static inline gboolean
 gst_message_replace (GstMessage **old_message, GstMessage *new_message)
@@ -470,28 +430,21 @@ gst_message_replace (GstMessage **old_message, GstMessage *new_message)
   return gst_mini_object_replace ((GstMiniObject **) old_message, (GstMiniObject *) new_message);
 }
 
-/**
- * gst_message_take:
- * @old_message: (inout) (transfer full): pointer to a pointer to a #GstMessage
- *     to be replaced.
- * @new_message: (transfer full) (allow-none): pointer to a #GstMessage that
- *     will replace the message pointed to by @old_message.
- *
- * Modifies a pointer to a #GstMessage to point to a different #GstMessage. This
- * function is similar to gst_message_replace() except that it takes ownership
- * of @new_message.
- *
- * Returns: %TRUE if @new_message was different from @old_message
- *
- * Since: 1.16
- */
 static inline gboolean
 gst_message_take (GstMessage **old_message, GstMessage *new_message)
 {
   return gst_mini_object_take ((GstMiniObject **) old_message,
       (GstMiniObject *) new_message);
 }
+#else /* GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS */
+GST_API
+gboolean  gst_message_replace                   (GstMessage ** old_message,
+                                                 GstMessage * new_message);
 
+GST_API
+gboolean  gst_message_take                      (GstMessage ** old_message,
+                                                 GstMessage * new_message);
+#endif /* GST_DISABLE_MINIOBJECT_INLINE_FUNCTIONS */
 
 /* custom messages */
 
@@ -509,6 +462,16 @@ GstStructure *  gst_message_writable_structure  (GstMessage *message);
 GST_API
 gboolean        gst_message_has_name            (GstMessage *message, const gchar *name);
 
+GST_API
+void            gst_message_set_details         (GstMessage *message, GstStructure *details);
+
+GST_API
+const GstStructure *
+                gst_message_get_details         (GstMessage *message);
+
+GST_API
+GstStructure *  gst_message_writable_details    (GstMessage *message);
+
 /* identifiers for events and messages */
 
 GST_API
@@ -536,6 +499,9 @@ void            gst_message_parse_error         (GstMessage *message, GError **g
 GST_API
 void            gst_message_parse_error_details (GstMessage *message, const GstStructure **structure);
 
+GST_API
+void            gst_message_parse_error_writable_details (GstMessage *message, GstStructure **structure);
+
 /* WARNING */
 
 GST_API
@@ -550,6 +516,9 @@ void            gst_message_parse_warning       (GstMessage *message, GError **g
 GST_API
 void            gst_message_parse_warning_details (GstMessage *message, const GstStructure **structure);
 
+GST_API
+void            gst_message_parse_warning_writable_details (GstMessage *message, GstStructure **structure);
+
 /* INFO */
 
 GST_API
@@ -564,6 +533,9 @@ void            gst_message_parse_info          (GstMessage *message, GError **g
 GST_API
 void            gst_message_parse_info_details  (GstMessage *message, const GstStructure **structure);
 
+GST_API
+void            gst_message_parse_info_writable_details  (GstMessage *message, GstStructure **structure);
+
 /* TAG */
 
 GST_API
